# Neural Graph Consensus library (ngclib)

This is a library containing the implementation of various basic block [nodes](ngclib/nodes/README.md), [models](ngclib/models/README.md) and [consensus algorithms](ngclib/voting_algorithms/README.md) used by various implementations of ngc consensus projects.

Example of projects:
- [Semi-Supervised Learning for Multi-Task Scene Understanding by Neural Graph Consensus](https://gitlab.com/neural-graph-consensus/semisup-multitask-scene-understanding)
  - Paper accepted at AAAI2021
- [NGC Sota](https://gitlab.com/neural-graph-consensus/ngc-sota)
- [NGC Bootstrap](https://gitlab.com/neural-graph-consensus/ngc-bootstrap)
- [NGC SpaceTime](https://gitlab.com/neural-graph-consensus/ngc-spacetime)

